Learn R Programming

wahc (version 1.0)

wahc-package: Autocorrelation and Heteroskedasticity Correction in Fixed Effect Panel Data Model

Description

Fit the fixed effect panel data model with heteroskedasticity and autocorrelation correction.

Arguments

Details

Package:
wahc
Type:
Package
Version:
1.0
Date:
2015-02-23
License:
GPL-3
In this package, we apply the consistent (HAC) standard errors to deal with both problems heteroskedasticity and autocorrelation in the fixed effect panel data regression.

References

Bhargava A, Franzini L, Narendranathan W (1982). Serial Correlation and the Fixed Effects Model.Review of Economic Studies,49, pp.533--554.

Drukker D (2003), Testing for Serial Correlation in Linear Panel-Data Models.The Stata Journal,3, pp. 168--177.

MacKinnon J, White H (1985), Some Heteroskedasticity-Consistent Covariance Matrix Es- timators With Improved Finite Sample Propertie,Journal of econometrics, 29, pp.305--325.

Zeileis A (2004). Econometric Computing With HC and HAC Covariance Matrix Estimators.Journal of Statistical Software, 11,pp. 1--17.